@@ -6,7 +6,7 @@ use I18N::Handle::Locale;
 use File::Find::Rule;
 use Locale::Maketext::Lexicon ();
 
-our $VERSION = '0.041';
+our $VERSION = '0.042';
 
 has base => ( is => 'rw' );
 
@@ -157,6 +157,12 @@ sub _scan_locale_files {
     return %langs;
 }
 
+
+sub speaking {
+    my $self = shift;
+    return $self->current();
+}
+
 sub speak {
     my ($self,$lang) = @_;
     if( grep { $lang eq $_ } $self->can_speak ) {
